import threading
import time

import schedule
import telebot
from loguru import logger
from telebot import types

from src.entity.finance import get_net_win_by_telegram_id
from src.entity.pay_record import get_pay_failed_by_telegram_id
from src.entity.user import get_all_users
from src.entity.visual_list import text_count_by_telegram_id

TOKEN = '6013830443:AAGzq1Tgtr_ZejU7bv0mab14xOwi0_64d0w'
bot = telebot.TeleBot(TOKEN)


def load_registered_users():
    """
    Load registered users from the data source.
    """
    registered_users = set()
    for user in get_all_users():
        ids = user.telegram_ids.split(',')
        registered_users.update(map(int, ids))
    return registered_users


registered_users = load_registered_users()


def schedule_user_updates():
    """
    Schedule regular user updates.
    """
    schedule.every(1).hour.do(lambda: load_registered_users())
    thread = threading.Thread(target=run_schedule)
    thread.start()


def run_schedule():
    """
    Run scheduled tasks.
    """
    while True:
        schedule.run_pending()
        time.sleep(1)


def is_registered(user_id):
    """
    Check if a user is registered.
    """
    return user_id in registered_users


def registered_user_only(func):
    """
    Decorator to restrict access to registered users only.
    """

    def wrapper(message):
        if not is_registered(message.from_user.id):
            bot.send_message(message.chat.id, "您需要注册才能使用此功能")
            return
        return func(message)

    return wrapper


def create_menu():
    """
    Create a reply keyboard menu.
    """
    markup = types.ReplyKeyboardMarkup(resize_keyboard=True, one_time_keyboard=True)
    markup.row_width = 3
    markup.add(types.KeyboardButton("报数"),
               types.KeyboardButton("负盈利"),
               types.KeyboardButton("查失败"))
    return markup


@bot.message_handler(commands=['start'])
@registered_user_only
def handle_start(message):
    bot.send_message(message.chat.id, "菜单已生成：", reply_markup=create_menu())


@bot.message_handler(commands=['userid'])
def user_id(message):
    bot.reply_to(message, f"您的用户 ID 是: {message.from_user.id}")


@bot.message_handler(func=lambda message: True)
@registered_user_only
def handle_message(message):
    # 获取用户id
    telegram_id = message.from_user.id
    response_mapping = {
        "报数": text_count_by_telegram_id(telegram_id),
        "负盈利": get_net_win_by_telegram_id(telegram_id),
        "查失败": get_pay_failed_by_telegram_id(telegram_id)
    }

    response = response_mapping.get(message.text, "未知选项")
    bot.send_message(message.chat.id, response)


def start_polling():
    while True:
        try:
            bot.polling(none_stop=True)
        except Exception as e:
            logger.error(f"长轮询异常: {e}")
            # 在重新尝试前暂停一段时间
            time.sleep(15)


if __name__ == "__main__":
    schedule_user_updates()  # 定时更新用户
    start_polling()  # 开始长轮询
