import re


def extract_urls(text):
    return re.findall(r'https?://\S+', text)


def read_file(filename):
    try:
        with open(filename, 'r') as file:
            return file.read()
    except IOError as e:
        print(f"Error reading file {filename}: {e}")
        raise


def write_file(filename, content):
    try:
        with open(filename, 'w') as file:
            file.write(content)
    except IOError as e:
        print(f"Error writing to file {filename}: {e}")
        raise


def replace_urls(js_content, url_mapping):
    for placeholder, url in url_mapping.items():
        js_content = js_content.replace(placeholder, url)
    return js_content


def get_hth_url_mapping(urls, is_seo):
    if is_seo:
        return {
            "{{hthApp}}": urls[4],
            "{{hthtyApp}}": urls[5],
            "{{hthPc}}": urls[0],
            "{{hthH5}}": urls[1]
        }
    else:
        return {
            "{{hthApp}}": urls[2],
            "{{hthtyApp}}": urls[3],
            "{{hthPc}}": urls[0],
            "{{hthH5}}": urls[1]
        }


def change_url(text):
    try:
        urls = extract_urls(text)
        expected_filename = None

        if len(urls) >= 10:
            js_content = read_file('ky.js.template')
            ky_url_mapping = {
                "{{kyApp1}}": urls[0],
                "{{kyApp2}}": urls[1],
                "{{kyPc1}}": urls[2],
                "{{kyPc2}}": urls[3],
                "{{kyH51}}": urls[4],
                "{{kyH52}}": urls[5]
            }
            updated_content = replace_urls(js_content, ky_url_mapping)
            expected_filename = 'ky.js'
            write_file(expected_filename, updated_content)
        elif len(urls) == 6:
            js_content = read_file('hth.js.template')
            is_seo = 'SEO' in text
            hth_url_mapping = get_hth_url_mapping(urls, is_seo)
            updated_content = replace_urls(js_content, hth_url_mapping)
            expected_filename = 'hth.js'
            write_file(expected_filename, updated_content)
        else:
            expected_filename = 'unknown.js'  # 或者选择适合的默认文件名

        # 如果一切顺利，返回 True 和预期的文件名
        return True, expected_filename
    except Exception as e:
        # 如果在过程中发生任何异常，打印错误并返回 False 和预期的文件名
        print(f"An error occurred: {e}")
        return False, expected_filename if expected_filename else 'unknown.js'
