import time

import schedule
from loguru import logger

from src.core.constant import BOT_TOKEN, COUNT_GROUP_ID
from src.core.message_client import send_message
from src.core.util import get_curr_day
from src.entity.finance import get_net_win_by_user
from src.entity.pay_record import get_pay_failed_by_user
from src.entity.user import get_user_by_username_and_password
from src.entity.visual_list import text_count_by_user


def job_count(username, password):
    logger.info(f'Running job_count for username: {username}')
    user = get_user_by_username_and_password(username, password)
    send_message(BOT_TOKEN, COUNT_GROUP_ID, text_count_by_user(user))
    logger.info(f'Finished job_count for username: {username}')


def query_failed_deposit(username, password):
    logger.info(f'Running query_failed_deposit for username: {username}')
    user = get_user_by_username_and_password(username, password)
    send_message(BOT_TOKEN, COUNT_GROUP_ID, get_pay_failed_by_user(user))
    logger.info(f'Finished query_failed_deposit for username: {username}')


def query_net_win(username, password) -> None:
    logger.info(f'Running query_net_win for username: {username}')
    user = get_user_by_username_and_password(username, password)
    send_message(BOT_TOKEN, COUNT_GROUP_ID, get_net_win_by_user(user,date=get_curr_day()))
    logger.info(f'Finished query_net_win for username: {username}')


if __name__ == '__main__':
    logger.info('Starting scheduled tasks')
    times = ['10:50', '14:40', '17:40', '20:40', '23:59']
    for time_str in times:
        schedule.every().day.at(time_str).do(job_count, 'zayac', '123456')
        schedule.every().day.at(time_str).do(query_net_win, 'zayac', '123456')
    schedule.every().day.at('23:59').do(query_failed_deposit, 'zayac', '123456')
    while True:
        schedule.run_pending()
        time.sleep(1)
        logger.info('Running scheduled tasks')
